exploristics_color: Add Exploristics colour to ggplot chart

Description Usage

View source: R/exploristics_color.R

Description

This function allows you to add the Exploristics colour to your ggplotgraphics. This function sets the colour of the graphs to a gradient matching the exploristics colour scheme

Usage

1

AntoniaPopescu/ExpTheme documentation built on Jan. 29, 2022, 7:13 a.m.