exploristics_fill: Add Exploristics fill to ggplot chart

Description Usage

View source: R/exploristics_fill.R

Description

This function allows you to add the Exploristics fill to your ggplotgraphics. This function sets the fill of the graphs to a gradient matching the exploristics colour scheme

Usage

1

AntoniaPopescu/ExpTheme documentation built on Jan. 29, 2022, 7:13 a.m.