exploristics_style: Add Exploristics theme to ggplot chart

Description Usage

View source: R/exploristics_style.R

Description

This function allows you to add the Exploristics theme to your ggplotgraphics. This function takes no arguments and is added to your ggplot to set axis, background, and title look to one matching the company's style.

Usage

1

AntoniaPopescu/ExpTheme documentation built on Jan. 29, 2022, 7:13 a.m.