View source: R/exploristics_fill.R
This function allows you to add the Exploristics fill to your ggplotgraphics. This function sets the fill of the graphs to a gradient matching the exploristics colour scheme
1 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.