View source: R/exploristics_style.R
This function allows you to add the Exploristics theme to your ggplotgraphics. This function takes no arguments and is added to your ggplot to set axis, background, and title look to one matching the company's style.
1 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.